@@ -140,6 +140,10 @@ def build_sphinx(
             )
             app.config.latex_documents = new_latex_documents
 
+            # set the below flag to always to enable maths in singlehtml builder
+            if app.builder.name == "singlehtml":
+                app.set_html_assets_policy("always")
+
             # setting up sphinx-multitoc-numbering
             if app.config["use_multitoc_numbering"]:
                 # if sphinx-external-toc is used
